@@ -5,8 +5,7 @@
   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef INCIDENCEEDITOR_ALARMPRESETS_H
-#define INCIDENCEEDITOR_ALARMPRESETS_H
+#pragma once
 
 #include <KCalendarCore/Alarm>
 
@@ -55,5 +54,3 @@ Q_REQUIRED_RESULT int presetIndex(When when, const KCalendarCore::Alarm::Ptr &al
 Q_REQUIRED_RESULT int defaultPresetIndex();
 }
 }
-
-#endif // INCIDENCEEDITOR_ALARMPRESETS_H
