@@ -36,6 +36,7 @@
 #include <KMessageBox>
 #include <QPointer>
 #include <QTreeView>
+#include <kwidgetsaddons_version.h>
 
 using namespace IncidenceEditorNG;
 
@@ -199,15 +200,24 @@ void IncidenceAttendee::save(const KCalendarCore::Incidence::Ptr &incidence)
             continue;
         }
         if (KEmailAddress::isValidAddress(attendee.email())) {
+#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
+            if (KMessageBox::warningTwoActions(nullptr,
+#else
             if (KMessageBox::warningYesNo(nullptr,
-                                          i18nc("@info",
-                                                "%1 does not look like a valid email address. "
-                                                "Are you sure you want to invite this participant?",
-                                                attendee.email()),
-                                          i18nc("@title:window", "Invalid Email Address"),
-                                          KGuiItem(i18nc("@action:button", "Invite"), QStringLiteral("dialog-ok")),
-                                          KGuiItem(i18nc("@action:button", "Do Not Invite"), QStringLiteral("dialog-cancel")))
+
+#endif
+                                               i18nc("@info",
+                                                     "%1 does not look like a valid email address. "
+                                                     "Are you sure you want to invite this participant?",
+                                                     attendee.email()),
+                                               i18nc("@title:window", "Invalid Email Address"),
+                                               KGuiItem(i18nc("@action:button", "Invite"), QStringLiteral("dialog-ok")),
+                                               KGuiItem(i18nc("@action:button", "Do Not Invite"), QStringLiteral("dialog-cancel")))
+#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
+                != KMessageBox::ButtonCode::PrimaryAction) {
+#else
                 != KMessageBox::Yes) {
+#endif
                 skip = true;
             }
         }
@@ -418,7 +428,8 @@ void IncidenceAttendee::insertAddresses(const KContacts::Addressee::List &list)
 void IncidenceAttendee::slotSelectAddresses()
 {
     QPointer<Akonadi::AbstractEmailAddressSelectionDialog> dialog;
-    const KPluginMetaData editWidgetPlugin(QStringLiteral("akonadi/emailaddressselectionldapdialogplugin"));
+    const KPluginMetaData editWidgetPlugin(QStringLiteral("pim" QT_STRINGIFY(QT_VERSION_MAJOR))
+                                           + QStringLiteral("/akonadi/emailaddressselectionldapdialogplugin"));
 
     const auto result = KPluginFactory::instantiatePlugin<Akonadi::AbstractEmailAddressSelectionDialog>(editWidgetPlugin, mParentWidget);
     if (result) {
@@ -771,21 +782,33 @@ void IncidenceAttendee::slotOrganizerChanged(const QString &newOrganizer)
         }
     }
 
-    int answer = KMessageBox::No;
+    int answer;
     if (currentOrganizerAttendee > -1) {
+#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
+        answer = KMessageBox::questionTwoActions(mParentWidget,
+#else
         answer = KMessageBox::questionYesNo(mParentWidget,
-                                            i18nc("@option",
-                                                  "You are changing the organizer of this event. "
-                                                  "Since the organizer is also attending this event, would you "
-                                                  "like to change the corresponding attendee as well?"),
-                                            QString(),
-                                            KGuiItem(i18nc("@action:button", "Change Attendee"), QStringLiteral("dialog-ok")),
-                                            KGuiItem(i18nc("@action:button", "Do Not Change"), QStringLiteral("dialog-cancel")));
+#endif
+                                                 i18nc("@option",
+                                                       "You are changing the organizer of this event. "
+                                                       "Since the organizer is also attending this event, would you "
+                                                       "like to change the corresponding attendee as well?"),
+                                                 QString(),
+                                                 KGuiItem(i18nc("@action:button", "Change Attendee"), QStringLiteral("dialog-ok")),
+                                                 KGuiItem(i18nc("@action:button", "Do Not Change"), QStringLiteral("dialog-cancel")));
     } else {
+#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
+        answer = KMessageBox::ButtonCode::PrimaryAction;
+#else
         answer = KMessageBox::Yes;
+#endif
     }
 
+#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
+    if (answer == KMessageBox::ButtonCode::PrimaryAction) {
+#else
     if (answer == KMessageBox::Yes) {
+#endif
         if (currentOrganizerAttendee > -1) {
             mDataModel->removeRows(currentOrganizerAttendee, 1);
         }
